/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 */
import { Plugin, EventListener } from '@boost/core';
import DriverContext from './contexts/DriverContext';
import { Argv, DriverCommandOptions, DriverOptions, DriverMetadata, Execution } from './types';
export default class Driver<T> extends Plugin<DriverOptions> {
    command: DriverCommandOptions;
    config: T;
    context: DriverContext;
    metadata: DriverMetadata;
    constructor(options?: Partial<DriverOptions>);
    /**
     * Format the configuration file before it's written.
     */
    formatConfig(data: T): string;
    /**
     * Return a list of user defined arguments.
     */
    getArgs(): Argv;
    /**
     * Return a list of dependent drivers.
     */
    getDependencies(): string[];
    /**
     * Return a list of supported CLI options.
     */
    getSupportedOptions(): string[];
    /**
     * Handle command failures according to this driver.
     */
    handleFailure(error: Execution): void;
    /**
     * Handle successful commands according to this driver.
     */
    handleSuccess(response: Execution): void;
    /**
     * Special case for merging arrays.
     */
    handleMerge(prevValue: any, nextValue: any): any;
    /**
     * Merge multiple configuration objects.
     */
    mergeConfig(prev: T, next: T): T;
    /**
     * Easily register events in the tool.
     */
    on(eventName: string, listener: EventListener): this;
    /**
     * Setup additional command options.
     */
    setCommandOptions(options: DriverCommandOptions): this;
    /**
     * Set metadata about the binary/executable in which this driver wraps.
     */
    setMetadata(metadata: Partial<DriverMetadata>): this;
}
