/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 */
/// <reference types="yargs" />
import Context from './Context';
import Driver from '../Driver';
import { Arguments, Argv } from '../types';
export interface ConfigPath {
    driver: string;
    path: string;
}
export default class DriverContext extends Context {
    configPaths: ConfigPath[];
    driverName: string;
    drivers: Set<Driver<any>>;
    parallelArgv: Argv[];
    primaryDriver: Driver<any>;
    workspaceRoot: string;
    workspaces: string[];
    constructor(args: Arguments, driver: Driver<any>, parallelArgv?: Argv[]);
    /**
     * Add a config path for the defined driver.
     */
    addConfigPath(driverName: string, path: string): this;
    /**
     * Add a driver as a dependency.
     */
    addDriverDependency(driver: Driver<any>): this;
    /**
     * Add a parallel command with additional argv.
     */
    addParallelCommand(argv: Argv): this;
    /**
     * Find a configuration path by file name.
     */
    findConfigByName(name: string): ConfigPath | undefined;
}
