"use strict";
/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Context_1 = __importDefault(require("./Context"));
const Driver_1 = __importDefault(require("../Driver"));
class DriverContext extends Context_1.default {
    constructor(args, driver, parallelArgv = []) {
        super(args);
        this.configPaths = [];
        this.driverName = '';
        this.drivers = new Set();
        this.parallelArgv = [];
        this.workspaceRoot = '';
        this.workspaces = [];
        this.driverName = driver.name;
        this.parallelArgv = parallelArgv;
        this.primaryDriver = driver;
        // Make the context available in the current driver
        driver.context = this;
    }
    /**
     * Add a config path for the defined driver.
     */
    addConfigPath(driverName, path) {
        this.configPaths.push({
            driver: driverName,
            path,
        });
        return this;
    }
    /**
     * Add a driver as a dependency.
     */
    addDriverDependency(driver) {
        if (driver instanceof Driver_1.default) {
            this.drivers.add(driver);
        }
        else {
            throw new TypeError('Invalid driver. Must be an instance of `Driver`.');
        }
        return this;
    }
    /**
     * Add a parallel command with additional argv.
     */
    addParallelCommand(argv) {
        this.parallelArgv.push(argv);
        return this;
    }
    /**
     * Find a configuration path by file name.
     */
    findConfigByName(name) {
        return this.configPaths.find(config => config.path.endsWith(name) || config.driver === name);
    }
}
exports.default = DriverContext;
