"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const rimraf_1 = __importDefault(require("rimraf"));
const BabelDriver_1 = __importDefault(require("../src/BabelDriver"));
const helpers_1 = require("../../../tests/helpers");
jest.mock('rimraf');
describe('BabelDriver', () => {
    let driver;
    beforeEach(() => {
        driver = new BabelDriver_1.default();
        driver.tool = helpers_1.createTestTool();
        driver.context = helpers_1.createDriverContext(driver);
        driver.bootstrap();
    });
    it('sets options from constructor', () => {
        driver = new BabelDriver_1.default({
            args: ['--foo', '--bar=1'],
            dependencies: ['babel'],
            env: { DEV: 'true' },
        });
        expect(driver.options).toEqual({
            args: ['--foo', '--bar=1'],
            dependencies: ['babel'],
            env: { DEV: 'true' },
            strategy: 'native',
        });
    });
    it('sets correct metadata', () => {
        expect(driver.metadata).toEqual(expect.objectContaining({
            bin: 'babel',
            configName: 'babel.config.js',
            configOption: '--config-file',
            dependencies: [],
            description: 'Transpile files with Babel',
            filterOptions: false,
            helpOption: '--help',
            title: 'Babel',
            useConfigOption: false,
        }));
    });
    describe('handleCleanTarget()', () => {
        it('doesnt run if no clean param', () => {
            driver.context.args.outDir = './lib';
            driver.handleCleanTarget(driver, [], driver.context);
            expect(rimraf_1.default.sync).not.toHaveBeenCalled();
        });
        it('doesnt run if no outDir param', () => {
            driver.context.args.clean = true;
            driver.handleCleanTarget(driver, [], driver.context);
            expect(rimraf_1.default.sync).not.toHaveBeenCalled();
        });
        it('runs if both params', () => {
            driver.context.args.outDir = './lib';
            driver.context.args.clean = true;
            driver.handleCleanTarget(driver, [], driver.context);
            expect(rimraf_1.default.sync).toHaveBeenCalledWith(path_1.default.resolve('./lib'));
        });
    });
});
