"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
// @ts-ignore
const yargs_parser_1 = __importDefault(require("yargs-parser"));
const core_1 = require("@boost/core");
const Driver_1 = __importDefault(require("../packages/core/src/Driver"));
const Context_1 = __importDefault(require("../packages/core/src/contexts/Context"));
const DriverContext_1 = __importDefault(require("../packages/core/src/contexts/DriverContext"));
const ScaffoldContext_1 = __importDefault(require("../packages/core/src/contexts/ScaffoldContext"));
const ScriptContext_1 = __importDefault(require("../packages/core/src/contexts/ScriptContext"));
exports.EXEC_RESULT = {
    cmd: '',
    code: 0,
    failed: false,
    killed: false,
    signal: null,
    stderr: '',
    stdout: '',
    timedOut: false,
};
function createTestDebugger() {
    const debug = jest.fn();
    // @ts-ignore
    debug.invariant = jest.fn();
    return debug;
}
exports.createTestDebugger = createTestDebugger;
function createTestTool() {
    const tool = new core_1.Tool({
        appName: 'beemo',
        configBlueprint: {},
        configFolder: './configs',
        console: {},
        pluginAlias: 'driver',
        root: __dirname,
        scoped: true,
        workspaceRoot: __dirname,
    });
    tool.config = {
        config: {
            cleanup: false,
            parallel: true,
        },
        debug: false,
        extends: [],
        plugins: [],
        reporters: [],
        settings: {},
    };
    tool.package = {
        name: '',
    };
    tool.initialized = true;
    // Mock
    tool.on = jest.fn().mockReturnThis();
    tool.debug = createTestDebugger();
    tool.createDebugger = createTestDebugger;
    return tool;
}
exports.createTestTool = createTestTool;
function createTestDriver(name, tool = null, metadata = {}) {
    const driver = new Driver_1.default();
    driver.name = name;
    driver.tool = tool || createTestTool();
    driver.setMetadata(Object.assign({ bin: name, configName: `${name}.json`, title: name }, metadata));
    driver.bootstrap();
    return driver;
}
exports.createTestDriver = createTestDriver;
function applyContext(context) {
    context.args = yargs_parser_1.default(['-a', '--foo', 'bar', 'baz']);
    context.argv = ['-a', '--foo', 'bar', 'baz'];
    context.moduleRoot = __dirname;
    context.root = __dirname;
    return context;
}
exports.applyContext = applyContext;
function createContext() {
    return applyContext(new Context_1.default({ _: [], $0: '' }));
}
exports.createContext = createContext;
function createDriverContext(driver = null) {
    return applyContext(new DriverContext_1.default({ _: [], $0: '' }, driver || new Driver_1.default()));
}
exports.createDriverContext = createDriverContext;
function createScaffoldContext(generator = 'generator', action = 'action') {
    return applyContext(new ScaffoldContext_1.default({ _: [], $0: '' }, generator, action));
}
exports.createScaffoldContext = createScaffoldContext;
function createScriptContext(script = null) {
    const context = applyContext(new ScriptContext_1.default({ _: [], $0: '' }, 'script'));
    if (script) {
        context.setScript(script, './script.js');
    }
    return context;
}
exports.createScriptContext = createScriptContext;
function prependRoot(part) {
    return path_1.default.join(__dirname, part);
}
exports.prependRoot = prependRoot;
function getRoot() {
    return __dirname;
}
exports.getRoot = getRoot;
function getFixturePath(part) {
    return path_1.default.join(__dirname, 'fixtures', part);
}
exports.getFixturePath = getFixturePath;
